@@ -1,4 +1,4 @@
-package Text::HTML::Turndown::Node 0.09;
+package Text::HTML::Turndown::Node 0.10;
 use 5.020;
 use Moo;
 use experimental 'signatures';
@@ -95,6 +95,10 @@ sub _has( $self, $nodeNames ) {
     }
 }
 
+sub firstNonBlankChild( $self ) {
+    return ([$self->_node->nonBlankChildNodes]->[0]);
+}
+
 sub isBlank( $self ) {
        !$self->isVoid
     && !$self->isMeaningfulWhenBlank
